@@ -23,14 +23,14 @@ class NodeGroupTemplate(base.Resource):
 class NodeGroupTemplateManager(base.ResourceManager):
     resource_class = NodeGroupTemplate
 
-    def _assign_field(self, name, plugin_name, hadoop_version, flavor_id,
-                      description=None, volumes_per_node=None,
-                      volumes_size=None, node_processes=None,
-                      node_configs=None, floating_ip_pool=None,
-                      security_groups=None, auto_security_group=None,
-                      availability_zone=None, volumes_availability_zone=None,
-                      volume_type=None, image_id=None, is_proxy_gateway=None,
-                      volume_local_to_instance=None):
+    def create(self, name, plugin_name, hadoop_version, flavor_id,
+               description=None, volumes_per_node=None, volumes_size=None,
+               node_processes=None, node_configs=None, floating_ip_pool=None,
+               security_groups=None, auto_security_group=None,
+               availability_zone=None, volumes_availability_zone=None,
+               volume_type=None, image_id=None, is_proxy_gateway=None,
+               volume_local_to_instance=None, use_autoconfig=None,
+               shares=None, is_public=None, is_protected=None):
 
         data = {
             'name': name,
@@ -48,7 +48,11 @@ class NodeGroupTemplateManager(base.ResourceManager):
                               auto_security_group=auto_security_group,
                               availability_zone=availability_zone,
                               image_id=image_id,
-                              is_proxy_gateway=is_proxy_gateway
+                              is_proxy_gateway=is_proxy_gateway,
+                              use_autoconfig=use_autoconfig,
+                              shares=shares,
+                              is_public=is_public,
+                              is_protected=is_protected
                               )
 
         if volumes_per_node:
@@ -63,45 +67,36 @@ class NodeGroupTemplateManager(base.ResourceManager):
                 data.update(
                     {"volume_local_to_instance": volume_local_to_instance})
 
-        return data
-
-    def create(self, name, plugin_name, hadoop_version, flavor_id,
-               description=None, volumes_per_node=None, volumes_size=None,
-               node_processes=None, node_configs=None, floating_ip_pool=None,
-               security_groups=None, auto_security_group=None,
-               availability_zone=None, volumes_availability_zone=None,
-               volume_type=None, image_id=None, is_proxy_gateway=None,
-               volume_local_to_instance=None):
-
-        data = self._assign_field(name, plugin_name, hadoop_version, flavor_id,
-                                  description, volumes_per_node, volumes_size,
-                                  node_processes, node_configs,
-                                  floating_ip_pool, security_groups,
-                                  auto_security_group, availability_zone,
-                                  volumes_availability_zone, volume_type,
-                                  image_id, is_proxy_gateway,
-                                  volume_local_to_instance)
-
         return self._create('/node-group-templates', data,
                             'node_group_template')
 
-    def update(self, ng_template_id, name, plugin_name, hadoop_version,
-               flavor_id, description=None, volumes_per_node=None,
-               volumes_size=None, node_processes=None, node_configs=None,
-               floating_ip_pool=None, security_groups=None,
+    def update(self, ng_template_id, name=None, plugin_name=None,
+               hadoop_version=None, flavor_id=None, description=None,
+               volumes_per_node=None, volumes_size=None, node_processes=None,
+               node_configs=None, floating_ip_pool=None, security_groups=None,
                auto_security_group=None, availability_zone=None,
                volumes_availability_zone=None, volume_type=None,
                image_id=None, is_proxy_gateway=None,
-               volume_local_to_instance=None):
+               volume_local_to_instance=None, use_autoconfig=None,
+               shares=None, is_public=None, is_protected=None):
 
-        data = self._assign_field(name, plugin_name, hadoop_version, flavor_id,
-                                  description, volumes_per_node, volumes_size,
-                                  node_processes, node_configs,
-                                  floating_ip_pool, security_groups,
-                                  auto_security_group, availability_zone,
-                                  volumes_availability_zone, volume_type,
-                                  image_id, is_proxy_gateway,
-                                  volume_local_to_instance)
+        data = {}
+        self._copy_if_defined(
+            data, name=name, plugin_name=plugin_name,
+            hadoop_version=hadoop_version, flavor_id=flavor_id,
+            description=description, volumes_per_node=volumes_per_node,
+            volumes_size=volumes_size, node_processes=node_processes,
+            node_configs=node_configs, floating_ip_pool=floating_ip_pool,
+            security_groups=security_groups,
+            auto_security_group=auto_security_group,
+            availability_zone=availability_zone,
+            volumes_availability_zone=volumes_availability_zone,
+            volume_type=volume_type, image_id=image_id,
+            is_proxy_gateway=is_proxy_gateway,
+            volume_local_to_instance=volume_local_to_instance,
+            use_autoconfig=use_autoconfig, shares=shares,
+            is_public=is_public, is_protected=is_protected
+        )
 
         return self._update('/node-group-templates/%s' % ng_template_id, data,
                             'node_group_template')
